==> hvcg_iam_openapi_identity-0.0.9.crate: hvcg_iam_openapi_identity-0.0.9/docs/mutation_user_api.md <==
# mutation_user_api

All URIs are relative to *https://dev-sg.portal.hocvienconggiao.com*

Method | HTTP request | Description
------------- | ------------- | -------------
**activate_user**](mutation_user_api.md#activate_user) | **POST** /mutation-api/identity-service/users/activation | Activate a user
**create-user**](mutation_user_api.md#create-user) | **POST** /mutation-api/identity-service/users | Create user
**deactivate_user**](mutation_user_api.md#deactivate_user) | **POST** /mutation-api/identity-service/users/deactivation | Deactive user
**update-password**](mutation_user_api.md#update-password) | **PUT** /mutation-api/identity-service/users/update-password | update password


# **activate_user**
> models::User activate_user(ctx, inline_object2)
Activate a user

Activate user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **inline_object2** | [**InlineObject2**](InlineObject2.md)|  | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create-user**
> models::User create-user(ctx, user)
Create user

Create user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **user** | [**User**](User.md)| User object that needs to be added to the database | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deactivate_user**
> models::User deactivate_user(ctx, inline_object1)
Deactive user

Deactivate user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **inline_object1** | [**InlineObject1**](InlineObject1.md)|  | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update-password**
> models::User update-password(ctx, inline_object)
update password

Update user password

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **inline_object** | [**InlineObject**](InlineObject.md)|  | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> hvcg_iam_openapi_identity-0.1.1.crate: hvcg_iam_openapi_identity-0.1.1/docs/mutation_user_api.md <==
# mutation_user_api

All URIs are relative to *https://dev-sg.portal.hocvienconggiao.com*

Method | HTTP request | Description
------------- | ------------- | -------------
**activate_user**](mutation_user_api.md#activate_user) | **POST** /mutation-api/identity-service/users/activation | Activate a user
**create-user**](mutation_user_api.md#create-user) | **POST** /mutation-api/identity-service/users | Create user
**deactivate_user**](mutation_user_api.md#deactivate_user) | **POST** /mutation-api/identity-service/users/deactivation | Deactive user
**update-password**](mutation_user_api.md#update-password) | **PUT** /mutation-api/identity-service/users/update-password | update password
**update_user**](mutation_user_api.md#update_user) | **PUT** /mutation-api/identity-service/users/{id} | Update an existing user


# **activate_user**
> models::User activate_user(ctx, inline_object2)
Activate a user

Activate user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **inline_object2** | [**InlineObject2**](InlineObject2.md)|  | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create-user**
> models::User create-user(ctx, user)
Create user

Create user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **user** | [**User**](User.md)| User object that needs to be added to the database | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deactivate_user**
> models::User deactivate_user(ctx, inline_object1)
Deactive user

Deactivate user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **inline_object1** | [**InlineObject1**](InlineObject1.md)|  | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update-password**
> models::User update-password(ctx, inline_object)
update password

Update user password

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **inline_object** | [**InlineObject**](InlineObject.md)|  | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_user**
> models::User update_user(ctx, id, user)
Update an existing user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **id** | [****](.md)| ID of user to update | 
  **user** | [**User**](User.md)| User object that needs to be added to the database | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
